Changelog
=========

%%version%% (unreleased)
------------------------

New
~~~

- Add changelog.

- Add quick logger instantiation.

Bugfixes
~~~~~~~~

- Don’t parse args unless running as script.

- Fix CLI usage text.

- Fix examples.

- Fix packaging scripts.

- Update docs, fix requirements, and remove sphinx.

v0.8.13 (2016-01-01)
--------------------

Bugfixes
~~~~~~~~

- Fix new year bug.

v0.8.10 (2015-12-30)
--------------------

Bugfixes
~~~~~~~~

- Fix capitalization.

- Fix optional dependency parsing.

- Fix spacing and remove unneeded marker.

v0.8.9 (2015-12-30)
-------------------

Bugfixes
~~~~~~~~

- Fix conditional dependency configuration.

- Fix requirements.

v0.8.8 (2015-12-29)
-------------------

Bugfixes
~~~~~~~~

- Fix project name.

v0.8.7 (2015-12-29)
-------------------

Bugfixes
~~~~~~~~

- Add pygogo to script path.

- Add pygogo to test path.

v0.8.6 (2015-12-29)
-------------------

Bugfixes
~~~~~~~~

- Fix doccheck errors.

v0.8.5 (2015-12-29)
-------------------

Bugfixes
~~~~~~~~

- Add missing helper script.

v0.8.4 (2015-12-29)
-------------------

Bugfixes
~~~~~~~~

- Fix setup.py (again!)

v0.8.3 (2015-12-29)
-------------------

Bugfixes
~~~~~~~~

- Fix setup.py.

v0.8.2 (2015-12-29)
-------------------

Bugfixes
~~~~~~~~

- Fix travis.

v0.8.1 (2015-12-29)
-------------------

Bugfixes
~~~~~~~~

- Fix tox config and tests.

- Change helper script name.

- Fix spacing.

- Fix makefile error.

- Only clean once.

v0.8.0 (2015-12-25)
-------------------

Bugfixes
~~~~~~~~

- Fix sphinx.

- Fix tox.

- Fix lint errors.

- Fix tests.

v0.7.0 (2015-12-23)
-------------------

Bugfixes
~~~~~~~~

- Fix lint error.

v0.6.3 (2015-12-22)
-------------------

Bugfixes
~~~~~~~~

- Fix pylint errors.

- Fix pylint and make check optional.

- Don’t overwrite fmtrs argument.

v0.5.0 (2015-12-20)
-------------------

Bugfixes
~~~~~~~~

- Fix duplicate handler/filter bug.

- Fix tests.

- Fix assertion arg orders.

v0.4.0 (2015-12-19)
-------------------

New
~~~

- Add BOM formatter.

Bugfixes
~~~~~~~~

- Fix spelling and spacing.

- Fix lint errors.

- Fix example.

- Fix lint errors and add msecs to formatter.

- Remove ‘ascitime’ from StructuredFormatter.

- Use port if given.

- Fix docblocks.

v0.2.2 (2015-12-07)
-------------------

Bugfixes
~~~~~~~~

- Fix typo.


